<?php
$translations = array(
	'General_Locale' => 'is_IS.UTF-8',
	'General_TranslatorName' => 'Anna Jonna Ármannsdóttir <annaj@hi.is>Ívar Björn Hilmarsson <ivarbj@hi.is>Jóhann B. Guðmundsson <johannbg@gmail.com>',
	'General_TranslatorEmail' => 'annaj@hi.is, ivarbj@hi.is, johannbg@gmail.com',
	'General_EnglishLanguageName' => 'Icelandic',
	'General_OriginalLanguageName' => 'Íslenska',
	'General_HelloUser' => 'Halló, %s!',
	'General_OpenSourceWebAnalytics' => 'Opin hugbúnaðar vefgreining',
	'General_Dashboard' => 'Skjáborð',
	'General_DashboardForASpecificWebsite' => 'Skjáborð fyrir ákveðinn vef',
	'General_MultiSitesSummary' => 'Allir vefir',
	'General_AllWebsitesDashboard' => 'Skjáborð fyrir alla vefi',
	'General_API' => 'API',
	'General_Widgets' => 'aukahlutir',
	'General_Settings' => 'Stillingar',
	'General_GiveUsYourFeedback' => 'Sendu okkur athugasemdir!',
	'General_Unknown' => 'Óþekkt',
	'General_Required' => '%s er krafist',
	'General_NotValid' => '%s er ekki gilt',
	'General_Id' => 'Auðkenni',
	'General_Error' => 'Villa',
	'General_Warning' => 'Aðvörun',
	'General_BackToHomepage' => 'Til baka á Piwik heimasíðu',
	'General_Yes' => 'Já',
	'General_No' => 'Nei',
	'General_Delete' => 'Eyða',
	'General_Report' => 'Skýrsla',
	'General_Edit' => 'Breyta',
	'General_Download' => 'Sækja',
	'General_Ok' => 'Ok',
	'General_Close' => 'Loka',
	'General_OrCancel' => 'eða %s hætta við %s',
	'General_Logout' => 'Útskrá',
	'General_Username' => 'Notandanafn',
	'General_Description' => 'Lýsing',
	'General_Done' => 'Búið',
	'General_Name' => 'Nafn',
	'General_Value' => 'Gildi',
	'General_Details' => 'Smáatriði',
	'General_Default' => 'Sjálfgefið',
	'General_Date' => 'Dagsetning',
	'General_Period' => 'Tímabil',
	'General_ChooseDate' => 'Veldu dagsetningu',
	'General_Today' => 'Í dag',
	'General_Yesterday' => 'Í gær',
	'General_CurrentWeek' => 'Núverandi vika',
	'General_CurrentMonth' => 'Núverandi mánuður',
	'General_CurrentYear' => 'Núverandi ár',
	'General_DateRange' => 'Tímabil:',
	'General_LoadingData' => 'Sækir gögn...',
	'General_Loading_js' => 'Sæki...',
	'General_GoTo' => 'Fara í %s',
	'General_Next' => 'Næsta',
	'General_Previous' => 'Fyrra',
	'General_Search' => 'Leita',
	'General_Others' => 'Aðrir',
	'General_Table' => 'Tafla',
	'General_Piechart' => 'Kökurit',
	'General_TagCloud' => 'Klisjuský',
	'General_VBarGraph' => 'Lóðrétt stöplarit',
	'General_OpenInNewWindow_js' => 'Opna í nýjum glugga',
	'General_SaveImageOnYourComputer_js' => 'Til að vista myndina á tölvunni þinni, þarf að hægrismella á myndina og velja "Vista mynd sem..."',
	'General_Refresh' => 'Endurnýja síðuna',
	'General_Visitors' => 'Gestir',
	'General_ExportThisReport' => 'Flytja þetta gagnasett út á öðrum sniðum',
	'General_ExportAsImage_js' => 'Flytja út sem mynd',
	'General_YourChangesHaveBeenSaved' => 'Breytingarnarn þínar hafa verið vistaðar.',
	'General_ColumnNbUniqVisitors' => 'Einstakir gestir',
	'General_ColumnNbVisits' => 'Heimsóknir',
	'General_ColumnPercentageVisits' => '% Heimsóknir',
	'General_ColumnNbActions' => 'Aðgerðir',
	'General_ColumnMaxActions' => 'Hámark aðgerða í einni heimsókn',
	'General_ColumnSumVisitLength' => 'Heildartími gesta eytt á vefsíðu (í sekúndum)',
	'General_ColumnLabel' => 'Merki',
	'General_ColumnConversionRate' => 'Umbreytitíðni',
	'General_ColumnActionsPerVisit' => 'Aðgerðir per heimsókn',
	'General_VisitDuration' => 'Meðallengd heimsókna(í sekúndum)',
	'General_ColumnAvgTimeOnSite' => 'Meðaltíma eytt á vef',
	'General_ColumnBounceRate' => 'Skopptíðni',
	'General_ColumnExitRate' => 'Útgöngutíðni',
	'General_ColumnPageviews' => 'Síðuflettingar',
	'General_ColumnUniquePageviews' => 'Einstakar síðuflettingar',
	'General_ColumnBounces' => 'Skopp',
	'General_ColumnEntrances' => 'Innkomur',
	'General_ColumnExits' => 'Útgöngur',
	'General_ColumnAverageTimeOnPage' => 'Meðaltími eytt á síðu',
	'General_ColumnValuePerVisit' => 'Virði per heimsókn',
	'General_ColumnVisitsWithConversions' => 'Heimsóknir með viðskiptum',
	'General_YearsDays' => '%1$s ár %2$s dagar',
	'General_DaysHours' => '%1$s dagar %2$s klst',
	'General_HoursMinutes' => '%1$s klst %2$s mín',
	'General_MinutesSeconds' => '%1$s mín %2$ss',
	'General_Seconds' => '%ss',
	'General_Save' => 'Vista',
	'General_ForExampleShort' => 't.d.',
	'General_YouMustBeLoggedIn' => 'Þú verður að verainnskráð(ur) til að hafa aðgang að þessu.',
	'General_Website' => 'Vefur',
	'General_GeneralSettings' => 'Almennar stillingar',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Leyfa Piwik geymslu kveikjun þegar skýrslur eru skoðaðar í vafranum',
	'General_ArchivingInlineHelp' => 'Á meðal til hárrar umferðar vefna er mælst til þess að óvirkja Piwik geymslu sem kveikt er á frá vafra. Þess í stað mælum við með að þú setjir upp cronfærslu sem vinnur skýrslurnar á hverri klukkustund',
	'General_ArchivingTriggerDescription' => 'Mælt er með fyrir stærri Piwik uppsetningar að þú þurfir að %ssetja upp cronfærslu%s til að vinna skýrslurnar sjálfkrafa',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Sjá frekari upplýsingar í gögnunum%sofficial documentation%s',
	'General_NSeconds' => '%s sekúndur',
	'General_SmallTrafficYouCanLeaveDefault' => 'Á vefjum með litla umferðgeturðu notað sjálfgefna tímann %s sekúndur, og skoðað skýrlurnar í rauntíma.',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'Á vefsvæðum með umferð yfir meðallagi, er mælt með að úrvinnsla skýrslna sé ekki framkvæmd tíðar en á hálftíma fresti (%s sekúndur) eða á klukkustundar fresti (%s seconds).',
	'General_RequiresFlash' => 'Til að birta gröf í Piwik þarf Flash.',
	'General_GraphHelp' => 'Nánari upplýsingar um birtingu grafa í Piwik.',
	'General_NoDataForTagCloud' => 'Engin gögn fyrir þetta klisjuský.',
	'General_DisplaySimpleTable' => 'Sýna einfalda töflu.',
	'General_DisplayTableWithMoreMetrics' => 'Sýna töflu með mörgum mæligildum.',
	'General_DisplayTableWithGoalMetrics' => 'Sýna töflu með mælingum á markmið.',
	'General_YouAreViewingDemoShortMessage' => 'Núna ertu að skoða tilraunaútgáfu af Piwik',
	'General_DownloadFullVersion' => '%1$sDownload%2$s heildarútgáfuna! Kannaðu  %3$s',
	'General_NewUpdatePiwikX' => 'Ný uppfærsla: Piwik %s',
	'General_AboutPiwikX' => 'Um Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s er tiltækt. %2$sVinsamlegast uppfærðu núna!%3$s (sjá %4$schanges%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s er aðgengilegt. Vinsamlegast láttu umsjónaraðila vefsins vita.',
	'General_NewReportsWillBeProcessedByCron' => 'Þegar Piwik geymsla er ekki kveikt af vafra munu nýjar skýrslur verða unnar af crontab',
	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Skýrslur verða því unnar á einnar klukkustundar fresti.',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Ef geymsla er hraðvirk fyrir uppsetningu þína þá getur þú keyrt crontab færslu mun örar',
	'General_BackToPiwik' => 'Aftur í Piwik',
	'General_ShortMonth_1' => 'jan',
	'General_ShortMonth_2' => 'feb',
	'General_ShortMonth_3' => 'mar',
	'General_ShortMonth_4' => 'apr',
	'General_ShortMonth_5' => 'maí',
	'General_ShortMonth_6' => 'jún',
	'General_ShortMonth_7' => 'júl',
	'General_ShortMonth_8' => 'ágú',
	'General_ShortMonth_9' => 'sep',
	'General_ShortMonth_10' => 'okt',
	'General_ShortMonth_11' => 'nóv',
	'General_ShortMonth_12' => 'des',
	'General_LongMonth_1' => 'janúar',
	'General_LongMonth_2' => 'febrúar',
	'General_LongMonth_3' => 'mars',
	'General_LongMonth_4' => 'apríl',
	'General_LongMonth_5' => 'maí',
	'General_LongMonth_6' => 'júní',
	'General_LongMonth_7' => 'júlí',
	'General_LongMonth_8' => 'ágúst',
	'General_LongMonth_9' => 'september',
	'General_LongMonth_10' => 'október',
	'General_LongMonth_11' => 'nóvember',
	'General_LongMonth_12' => 'desember',
	'General_ShortDay_1' => 'mán',
	'General_ShortDay_2' => 'þri',
	'General_ShortDay_3' => 'mið',
	'General_ShortDay_4' => 'fim',
	'General_ShortDay_5' => 'fös',
	'General_ShortDay_6' => 'lau',
	'General_ShortDay_7' => 'sun',
	'General_LongDay_1' => 'mánudagur',
	'General_LongDay_2' => 'þriðjudagur',
	'General_LongDay_3' => 'miðvikudagur',
	'General_LongDay_4' => 'fimtudagur',
	'General_LongDay_5' => 'föstudagur',
	'General_LongDay_6' => 'laugardagur',
	'General_LongDay_7' => 'sunnudagur',
	'General_Daily' => 'Daglega',
	'General_Weekly' => 'Vikulega',
	'General_Monthly' => 'Mánaðalega',
	'General_ExceptionMissingFile' => 'Töpuð skrá: %s',
	'General_ExceptionFilesizeMismatch' => 'Skráarstærðar mismunur: %1$s (bjóst við lengd: %2$s, fann: %3$s)',
	'General_ExceptionFileIntegrity' => 'Heiðarleika athuga féll: %s',
	'General_ExceptionNonceMismatch' => 'Gat ekki valið öryggis tóka á þessu formi.',
	'General_PleaseSpecifyValue' => 'Vinsamlegast settu gildi í %s.',
	'General_SmtpServerAddress' => 'SMTP veffang',
	'General_SmtpPort' => 'SMTP gátt',
	'General_SmtpUsername' => 'SMTP notendanafn',
	'General_SmtpPassword' => 'SMTP lykilorð',
	'General_SmtpEncryption' => 'SMTP dulritun',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Veldu "Já" ef þig langar að verður að senda tölvupóst í gegnum nefndan þjón í staðin fyrir staðbundna póstvirkni',
	'General_OptionalSmtpPort' => 'Valmögulegt. Sjálgefið er gátt 25 fyrir ódulkóðuð samskipti og einnig fyrir TLS SMTP, en gátt 465 fyrir dulkóða SSL SMTP samskipti.',
	'General_OnlyEnterIfRequired' => 'Einungis slá inn notendanafn ef SMTP þjónninn krefst þess.',
	'General_OnlyEnterIfRequiredPassword' => 'Einungis slá inn lykilorð ef SMTP þjónninn krefst þess.',
	'General_WarningPasswordStored' => '%sVarist:%s Þetta lykilorð mun vera vistað í stillingar skrá sem er sýnileg öllum sem hafa næga aðgangsheimild.',
	'General_EncryptedSmtpTransport' => 'Veldu þá dulritun sem þarf fyrir dulritaða flutningslagið á þínum SMTP þjóni.',
	'General_InvalidResponse' => 'Mótteknu gögnin eru ógild.',
	'General_ChooseLanguage' => 'Veldu tungumál',
	'General_ChoosePeriod' => 'Veldu tímabil',
	'General_ChooseWebsite' => 'Veldu vef',
	'General_Language' => 'Tungumál',
	'General_PleaseUpdatePiwik' => 'Vinsamlegast uppfærðu Piwik',
	'General_RequestTimedOut' => 'Gagnafyrirspurnin til %s rann út á tíma. Vinsamlegast reynið aftur.',
	'Actions_PluginDescription' => 'Skýrslur um flettingar, hlekki út og niðurhal. Hlekkir út og niðurhals mælingar eru sjálfvirkar!',
	'Actions_Actions' => 'Aðgerðir',
	'Actions_SubmenuPages' => 'Síður',
	'Actions_SubmenuPagesEntry' => 'Inngangssíður',
	'Actions_SubmenuPagesExit' => 'Útgangssíður',
	'Actions_SubmenuPageTitles' => 'Síðu titlar',
	'Actions_SubmenuOutlinks' => 'Hlekkir út',
	'Actions_SubmenuDownloads' => 'Niðurhal',
	'Actions_ColumnClicks' => 'Músasmellir',
	'Actions_ColumnUniqueClicks' => 'Einstakir músasmellir',
	'Actions_ColumnDownloads' => 'Niðurhal',
	'Actions_ColumnUniqueDownloads' => 'Einstakt niðurhal',
	'Actions_ColumnPageName' => 'Síðu nafn',
	'Actions_ColumnPageURL' => 'Síðu slóð',
	'Actions_ColumnClickedURL' => 'Músarsmellt slóð',
	'Actions_ColumnDownloadURL' => 'Niðurhals slóð',
	'AnonymizeIP_PluginDescription' => 'Hylja síðusta bæti gesta IP-tölu til samræðis við persónuverndarlaga þíns lands.',
	'API_PluginDescription' => 'Öll gögn í Piwik eru til boði í gegnum einfalt API. Þessi íbót er vefþjónustu inngangur sem þú getur kallað í til fá þín vefgögn í xml JSON, PHP, csv, o.fl.',
	'API_QuickDocumentationTitle' => 'API hraðskjöl.',
	'API_GenerateVisits' => 'Ef þú hefur ekki gögn dagsins í dag verður þú fyrst að búa til gögn með að nota %s íbótina. Virkjaðu %s íbótina og smelltu síðan á valmyndinni \'Gesta framleiðni\' í Piwik umsjónarmanns svæðinu.',
	'API_MoreInformation' => 'Fyrir frekari upplýsingar um Piwik API, Vinsamlegast skoðið %s Inngangur að Piwik API %s og %s Piwik API Tilvísunir %s.',
	'API_UserAuthentication' => 'Notenda auðkenning',
	'API_UsingTokenAuth' => 'Ef þú vilt að %s biðji um gögn inn í skriftu eða crontab færslu osfv. %s verður þú að bæta við færibreytu %s til API kalls vefslóðir sem krefst auðkenningar.',
	'API_KeepTokenSecret' => 'Þessi tókar auðkenning er eins leynd og þitt notendanafn og lykilorð %s deilið því ekki%s!',
	'API_LoadedAPIs' => 'Tókst að hlaða %s API',
	'CoreAdminHome_PluginDescription' => 'Umsjónarsvæði Piwik',
	'CoreAdminHome_MenuGeneralSettings' => 'Almennar stillingar',
	'CoreAdminHome_Administration' => 'Umsjón',
	'CoreAdminHome_EmailServerSettings' => 'Póstþjóns stillingar',
	'CoreAdminHome_OptOutForYourVisitors' => 'Piwik er útvalið fyrir þína gesti',
	'CoreAdminHome_OptOutExplanation' => 'Piwik er tileinkað að bjóða uppá persónuvernd á netinu. Til að veita gestum þínum val á að kjósa ekki að taka þátt í Piwik vefumferðar mælingum þá getur þú bætt við eftirfarandi HTML kóða á eina af síðum vefjarins tildæmis á persónuverndarstefnu síðunni.',
	'CoreAdminHome_YouMayOptOutBis' => 'Til að framkvæma það val, vinsamlegast smelltu hér fyrir neðan til að fá útvals smáköku.',
	'CoreAdminHome_YouAreOptedIn' => 'Þú ert nú valinn',
	'CoreAdminHome_YouAreOptedOut' => 'Þú ert nú útvalinn',
	'CoreHome_ThereIsNoDataForThisReport' => 'Það eru eingin gögn til fyrir þessa skýrslu',
	'CoreHome_ShowJSCode' => 'Sýna JavaScript kóða til að setja inn',
	'CoreHome_PageOf_js' => '%1$s of %2$s',
	'CoreHome_PeriodDay' => 'Dagur',
	'CoreHome_PeriodWeek' => 'Vika',
	'CoreHome_PeriodMonth' => 'Mánuður',
	'CoreHome_PeriodYear' => 'Ár',
	'CoreHome_PeriodDays' => 'daga',
	'CoreHome_PeriodWeeks' => 'vikur',
	'CoreHome_PeriodMonths' => 'mánuði',
	'CoreHome_PeriodYears' => 'ár',
	'General_DaySu_js' => 'su',
	'General_DayMo_js' => 'má',
	'General_DayTu_js' => 'þr',
	'General_DayWe_js' => 'mi',
	'General_DayTh_js' => 'fi',
	'General_DayFr_js' => 'fö',
	'General_DaySa_js' => 'la',
	'General_ShortDay_1_js' => 'sun',
	'General_ShortDay_2_js' => 'mán',
	'General_ShortDay_3_js' => 'þri',
	'General_ShortDay_4_js' => 'mið',
	'General_ShortDay_5_js' => 'fim',
	'General_ShortDay_6_js' => 'fös',
	'General_ShortDay_7_js' => 'lau',
	'General_LongDay_1_js' => 'sunnudagur',
	'General_LongDay_2_js' => 'mánudagur',
	'General_LongDay_3_js' => 'þriðjudagur',
	'General_LongDay_4_js' => 'miðvikudagur',
	'General_LongDay_5_js' => 'fimtudagur',
	'General_LongDay_6_js' => 'föstudagur',
	'General_LongDay_7_js' => 'laugardagur',
	'General_ShortMonth_1_js' => 'jan',
	'General_ShortMonth_2_js' => 'feb',
	'General_ShortMonth_3_js' => 'mar',
	'General_ShortMonth_4_js' => 'apr',
	'General_ShortMonth_5_js' => 'maí',
	'General_ShortMonth_6_js' => 'jún',
	'General_ShortMonth_7_js' => 'júl',
	'General_ShortMonth_8_js' => 'ágú',
	'General_ShortMonth_9_js' => 'sep',
	'General_ShortMonth_10_js' => 'okt',
	'General_ShortMonth_11_js' => 'nóv',
	'General_ShortMonth_12_js' => 'des',
	'General_MonthJanuary_js' => 'janúar',
	'General_MonthFebruary_js' => 'febrúar',
	'General_MonthMarch_js' => 'mars',
	'General_MonthApril_js' => 'apríl',
	'General_MonthMay_js' => 'maí',
	'General_MonthJune_js' => 'júní',
	'General_MonthJuly_js' => 'júlí',
	'General_MonthAugust_js' => 'ágúst',
	'General_MonthSeptember_js' => 'september',
	'General_MonthOctober_js' => 'október',
	'General_MonthNovember_js' => 'nóvember',
	'General_MonthDecember_js' => 'desember',
	'CorePluginsAdmin_PluginDescription' => 'Viðmót fyrir Íbótastjórnun',
	'CorePluginsAdmin_Plugins' => 'Íbætur',
	'CorePluginsAdmin_PluginsManagement' => 'Íbótastjórnun',
	'CorePluginsAdmin_MainDescription' => 'Íbætur auka og víkka virknina í Piwik. Hérna geturðu kveikteða slökkt á íbót þegar búið er að setja hana inn í kerfið.',
	'CorePluginsAdmin_Plugin' => 'Íbót',
	'CorePluginsAdmin_Version' => 'Útgáfa',
	'CorePluginsAdmin_Status' => 'Staða',
	'CorePluginsAdmin_Action' => 'Aðgerð',
	'CorePluginsAdmin_AuthorHomepage' => 'Heimasíða höfundar',
	'CorePluginsAdmin_LicenseHomepage' => 'Heimasíða hugbúnaðarleyfis',
	'CorePluginsAdmin_PluginHomepage' => 'Heimasíða íbótar',
	'CorePluginsAdmin_Activated' => 'Kveikt',
	'CorePluginsAdmin_Active' => 'Kveikt',
	'CorePluginsAdmin_Inactive' => 'Slökkt',
	'CorePluginsAdmin_Deactivate' => 'Slökkva',
	'CorePluginsAdmin_Activate' => 'Kveikja',
	'CorePluginsAdmin_MenuPlugins' => 'Íbætur',
	'Dashboard_PluginDescription' => 'Vefgreiningarskjáborðið þitt. Þú getur sérsniðið skjáborðið þitt: bætt við nýjum aukahlutum, breytt uppröðun aukahluta. Sérhver notandi hefur aðgang að sínu eigin sérsniðna skjáborði.',
	'Dashboard_Dashboard' => 'Skjáborð',
	'Dashboard_DeleteWidgetConfirm' => 'Ertu viss um að þú viljir eyða þessum aukahlut af skjáborðinu.',
	'Dashboard_SelectWidget' => 'Veldu aukahlutinn til að bæta við skjáborðið',
	'Dashboard_AddPreviewedWidget_js' => 'Bæta forskoðuðum aukahlut á skjáborðið',
	'Dashboard_WidgetPreview_js' => 'Forskoðun á aukahlut',
	'Dashboard_Close_js' => 'Loka',
	'Dashboard_Maximise_js' => 'Hámarka',
	'Dashboard_TitleWidgetInDashboard_js' => 'Aukahlutur er núþegar á skjáborði',
	'Dashboard_TitleClickToAdd_js' => 'Smella til að bæta á skjáborð',
	'Dashboard_LoadingWidget_js' => 'Hleð inn aukahlut, vinsamlegast bíðið...',
	'Dashboard_WidgetNotFound_js' => 'Aukahlutur fannst ekki',
	'DBStats_PluginDescription' => 'Þessi íbót birtir MySQL gagnagrunnsnotkun á töflum Piwik.',
	'DBStats_DatabaseUsage' => 'Notkun gagnagrunns',
	'DBStats_MainDescription' => 'Piwik vistar öll vefgreiningagögn inn í MySQL gagnagrunn. Núna eru Piwik töflurnar að nota %s.',
	'DBStats_Table' => 'Tafla',
	'DBStats_RowCount' => 'Fjöldi raða',
	'DBStats_DataSize' => 'Gagnastærð',
	'DBStats_IndexSize' => 'stærð vísitöflu',
	'DBStats_TotalSize' => 'Heildarstærð',
	'ExampleAPI_PluginDescription' => 'Dæmi íbót: Hvernig á að búa til API fyrir þína íbót til að flytja gögn þín í mörgum sniðum án sérstakar kóðunar?',
	'Goals_Goals' => 'Markmið',
	'Goals_GoalsOverview' => 'Yfirlit Markmiða',
	'Goals_GoalsManagement' => 'Markmiðastjórnun',
	'Goals_ColumnConversions' => 'Umbreytingar',
	'Goals_ColumnRevenue' => 'Hagnaður',
	'Goals_GoalX' => 'Markmið %s',
	'Goals_GoalConversion' => 'Umbreyting markmiðs',
	'Goals_OverallRevenue' => '%s heildarhagnaður',
	'Goals_OverallConversionRate' => '%s heildar umbreytingatíðni (heimsóknir sem hafa náð markmiði)',
	'Goals_Conversions' => '%s umbreytingar',
	'Goals_ConversionRate' => '%s umbreytingatíðni',
	'Goals_AddNewGoal' => 'Bæta nýju markmiði við',
	'Goals_AddNewGoalOrEditExistingGoal' => '%sAdd a new Goal%s eða %sEdit%s núverandi Markmiðum',
	'Goals_AddGoal_js' => 'Bæta Markmiði við',
	'Goals_UpdateGoal_js' => 'Uppfæra Markmið',
	'Goals_DeleteGoalConfirm_js' => 'Ertu viss um að þú viljir eyða markmiðinu %s?',
	'Goals_CreateNewGOal' => 'Búa til nýtt Markmið',
	'Goals_ViewAndEditGoals' => 'Skoða og breyta Markmiðum',
	'Goals_GoalName' => 'Nafn Markmiðs',
	'Goals_GoalIsTriggered' => 'Markmiðið er kveikt',
	'Goals_GoalIsTriggeredWhen' => 'Markmiðið er kveikt þegar',
	'Goals_WhenVisitors' => 'þegar gestir',
	'Goals_WhereThe' => 'þar sem',
	'Goals_Manually' => 'handvirkt',
	'Goals_ManuallyTriggeredUsingJavascriptFunction' => 'Markmið er kveikt handvirkt með því að nota JavaScript API trackGoal()',
	'Goals_VisitUrl' => 'Skoða gefinn URL (vefsíðu eða hóp síðna)',
	'Goals_URL' => 'URL',
	'Goals_Filename' => 'skrárnafn',
	'Goals_ExternalWebsiteUrl' => 'utanaðkumandi vefslóð URL',
	'Goals_Download' => 'Sækja skrá',
	'Goals_ClickOutlink' => 'Smella á slóð fyrir utan vefinn',
	'Goals_Optional' => '(valkvætt)',
	'Goals_Contains' => 'inniheldur %s',
	'Goals_IsExactly' => 'er nákvæmlega %s',
	'Goals_MatchesExpression' => 'upfyllir skilyrðið %s',
	'Goals_CaseSensitive' => 'Skiptir máli hvort það eru hástafir eða lágstafir',
	'Goals_Pattern' => 'Mynstur',
	'Goals_LearnMoreAboutGoalTrackingDocumentation' => 'Læra meira um %s að rekja markmið í Piwik%s í notendaskjölum.',
	'LanguagesManager_PluginDescription' => 'Þessi íbót sýnir lista yfir öll tiltæk tungumál fyrir Piwik viðmótið. Tungumálið sem valið er, verður vistað í stillingum fyrir hvern notanda.',
	'LanguagesManager_AboutPiwikTranslations' => 'Um Þýðendur Piwik',
	'Live_PluginDescription' => 'Njósnaðu um gestina þína, í rauntíma!',
	'Live_LinkVisitorLog' => 'Skoða nákvæman heimsóknaannál',
	'Live_Actions' => 'Aðgerðir',
	'Live_Action' => 'Aðgerð',
	'Live_VisitorsInRealTime' => 'Gestir í rauntíma',
	'Live_VisitorLog' => 'Heimsóknaannáll',
	'Live_Time' => 'Tími',
	'Live_Referrer_URL' => 'URL Sendanda',
	'Live_LastMinutes' => 'Síðustu %s mínútur',
	'Live_LastHours' => 'Síðustu %s klukkustundir',
	'Live_GoalType' => 'Tegund',
	'Live_GoalRevenue' => 'Hagnaður',
	'Live_GoalDetails' => 'Smáatriði',
	'Login_LoginPasswordNotCorrect' => 'Notendanafn & Lykilroð ekki rétt',
	'Login_Password' => 'Lykilorð',
	'Login_PasswordRepeat' => 'Lykilorð (endurtekið)',
	'Login_ChangePassword' => 'Breyta lykilorði',
	'Login_LoginOrEmail' => 'Notendanafn eða tölvupóstfang',
	'Login_RememberMe' => 'Mundu mig',
	'Login_LogIn' => 'Innskrá',
	'Login_Logout' => 'Útskrá',
	'Login_LostYourPassword' => 'Tapaðirðu lykilroðinu?',
	'Login_PasswordsDoNotMatch' => 'Lykilorðin stemma ekki.',
	'Login_InvalidUsernameEmail' => 'Ekki gilt notendanafn og/eða tölvupóstfang',
	'Login_ContactAdmin' => 'Möguleg ástæða: þjónninn þinn gæti hafa slökkt á mail() fallinu. <br/>Vinsamlegast hafðu samband við umsjónarmann Piwik þjónsins.',
	'Login_ExceptionPasswordMD5HashExpected' => 'Búist er við að lykilorðs færibreytan sé MD5 dulmál af lykilorðinu.',
	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Ekki er hægt að auðkenna yfirnotandan með \'%s\' aðferðinni.',
	'Provider_PluginDescription' => 'Skilar gögnum um þá sem veita gestum á vefinn.',
	'Provider_WidgetProviders' => 'Veitendur',
	'Provider_ColumnProvider' => 'Veitandi',
	'Provider_SubmenuLocationsProvider' => 'Staðsetningar & Veitandi',
	'Referers_PluginDescription' => 'Gefur skýrslu um sendendur: Leitarvélar, Leitarorð, Vefi, rekja herferð, bein innfærsla.',
	'Referers_Referers' => 'Sendendur',
	'Referers_SearchEngines' => 'Leitarvélar',
	'Referers_Keywords' => 'Leitarorð',
	'Referers_DirectEntry' => 'Beinar Innfærslur',
	'Referers_Websites' => 'Vefir',
	'Referers_Campaigns' => 'Herferðir',
	'Referers_Evolution' => 'Þróun yfir tímabilið',
	'Referers_Type' => 'Tegund Sendanda',
	'Referers_ColumnRefererType' => 'Tegund Sendanda',
	'Referers_ColumnSearchEngine' => 'Leitarvél',
	'Referers_ColumnWebsite' => 'Vefur',
	'Referers_ColumnWebsitePage' => 'Vefsíða',
	'Referers_ColumnKeyword' => 'Leitarorð',
	'Referers_ColumnCampaign' => 'Herferð',
	'Referers_DetailsByRefererType' => 'Smáatriði eftir Tegund Sendanda',
	'Referers_TypeDirectEntries' => '%s beinar innfærslur',
	'Referers_TypeSearchEngines' => '%s frá leitarvélum',
	'Referers_TypeWebsites' => '%s frá vefjum',
	'Referers_TypeCampaigns' => '%s frá herferðum',
	'Referers_Distinct' => 'Mismundandi Sendendur eftir Tegund Sendanda',
	'Referers_DistinctSearchEngines' => 'mismunandi leitarvélar',
	'Referers_DistinctKeywords' => 'mismunandi leitarorð',
	'Referers_DistinctCampaigns' => 'mismunandi herferðir',
	'Referers_DistinctWebsites' => 'mismunandi vefir',
	'Referers_UsingNDistinctUrls' => '(notuð eru %s mismunandi url)',
	'Referers_SubmenuOverview' => 'Yfirlit',
	'Referers_SubmenuSearchEngines' => 'Leitarvélar & Leitarorð',
	'Referers_SubmenuWebsites' => 'Vefir',
	'Referers_SubmenuCampaigns' => 'Herferðir',
	'Referers_WidgetKeywords' => 'Listi yfir Leitarorð',
	'Referers_WidgetCampaigns' => 'Listi yfir Herferðir',
	'Referers_WidgetExternalWebsites' => 'Listi yfir ytri vefi',
	'Referers_WidgetSearchEngines' => 'Bestu leitarvélar',
	'Referers_WidgetOverview' => 'Yfirlit',
	'SitesManager_PluginDescription' => 'Stjórnun vefja í Piwik: Bættu við nýjum vef, Breyttu núverandi vef, Sýndu JavaScript kóðann sem á að vera á síðunum þínum. Allar aðgerðir eru einnig aðgengilegar gegnum API.',
	'SitesManager_Sites' => 'Vefir',
	'SitesManager_TrackingTags' => 'Eltir merkimiða fyrir %s',
	'SitesManager_WebsitesManagement' => 'Stjórnun Vefja',
	'SitesManager_JsTrackingTag' => 'Merkimiði sem er eltur (JavaScript)',
	'SitesManager_ShowTrackingTag' => 'Sýna merkimiða til að elta',
	'SitesManager_MenuSites' => 'Vefir',
	'SitesManager_ExcludedIps' => 'Útilokuð vistföng (IP)',
	'SitesManager_GlobalListExcludedIps' => 'Algildur listi af útilokuðum vistföngum (IP)',
	'SitesManager_Currency' => 'Gjaldmiðill',
	'TranslationsAdmin_PluginDescription' => 'Aðstoðaðu við að þýða Piwik á þitt tungumál.',
	'TranslationsAdmin_MenuTranslations' => 'Þýðingar',
	'TranslationsAdmin_MenuLanguages' => 'Tungumál',
	'TranslationsAdmin_LanguageCode' => 'Kóði tungumáls',
	'TranslationsAdmin_Plugin' => 'Íbót',
	'TranslationsAdmin_Definition' => 'Skilgreining',
	'TranslationsAdmin_DefaultString' => 'Sjálfgefinn strengur (Enska)',
	'TranslationsAdmin_TranslationString' => 'Þýðingarstrengur (núverandi tungumál: %s)',
	'TranslationsAdmin_Translations' => 'Þýðingar',
	'TranslationsAdmin_FixPermissions' => 'Vinsamlegast lagið heimildir skráakerfisins',
	'TranslationsAdmin_AddLanguage' => 'Bæta tungumáli við',
	'TranslationsAdmin_Export' => 'Flytja tungumál út',
	'TranslationsAdmin_Import' => 'Flytja tungumál inn',
	'TranslationsAdmin_ShowOnlyEmpty' => 'Sýna aðeins það sem ekki hefur verið þýtt',
	'UserCountry_PluginDescription' => 'Greinir frá hvaða landi gestirnir koma',
	'UserCountry_Country' => 'Land',
	'UserCountry_Continent' => 'Heimsálfa',
	'UserCountry_DistinctCountries' => '%s mismunandi lönd',
	'UserCountry_Location' => 'Staðsetning',
	'UserCountry_SubmenuLocations' => 'Staðsetningar',
	'UserCountry_country_ac' => '(Uppstigningareyja)Sankti Helena',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'Sameinuðu arabísku furstadæmin',
	'UserCountry_country_af' => 'Afganistan',
	'UserCountry_country_ag' => 'Antígva og Barbúda',
	'UserCountry_country_ai' => 'Angvilla',
	'UserCountry_country_al' => 'Albanía',
	'UserCountry_country_am' => 'Armenía',
	'UserCountry_country_an' => 'Hollensku Antillur',
	'UserCountry_country_ao' => 'Angóla',
	'UserCountry_country_aq' => 'Suðurskautslandið',
	'UserCountry_country_ar' => 'Argentína',
	'UserCountry_country_as' => 'Bandaríska Samóa',
	'UserCountry_country_at' => 'Austurríki',
	'UserCountry_country_au' => 'Ástralía',
	'UserCountry_country_aw' => 'Arúba',
	'UserCountry_country_ax' => 'Álandseyjar',
	'UserCountry_country_az' => 'Aserbaídsjan',
	'UserCountry_country_ba' => 'Bosnía og Hersegóvína',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladess',
	'UserCountry_country_be' => 'Belgía',
	'UserCountry_country_bf' => 'Búrkína Fasó',
	'UserCountry_country_bg' => 'Búlgaría',
	'UserCountry_country_bh' => 'Barein',
	'UserCountry_country_bi' => 'Búrúndí',
	'UserCountry_country_bj' => 'Benín',
	'UserCountry_country_bl' => 'Saint Barthélemy',
	'UserCountry_country_bm' => 'Bermúdaeyjar',
	'UserCountry_country_bn' => 'Brúnei',
	'UserCountry_country_bo' => 'Bólivía',
	'UserCountry_country_br' => 'Brasilía',
	'UserCountry_country_bs' => 'Bahamaeyjar',
	'UserCountry_country_bt' => 'Bútan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvet-eyja',
	'UserCountry_country_bw' => 'Botsvana',
	'UserCountry_country_by' => 'Hvíta-Rússland',
	'UserCountry_country_bz' => 'Belís',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cc' => 'Kókoseyjar',
	'UserCountry_country_cd' => 'Austur-Kongó',
	'UserCountry_country_cf' => 'Mið-Afríkulýðveldið',
	'UserCountry_country_cg' => 'Vestur-Kongó',
	'UserCountry_country_ch' => 'Sviss',
	'UserCountry_country_ci' => 'Fílabeinsströndin',
	'UserCountry_country_ck' => 'Cooks-eyjar',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Kamerún',
	'UserCountry_country_cn' => 'Kína',
	'UserCountry_country_co' => 'Kólumbía',
	'UserCountry_country_cr' => 'Kostaríka',
	'UserCountry_country_cs' => 'Serbía Svartfjallaland',
	'UserCountry_country_cu' => 'Kúba',
	'UserCountry_country_cv' => 'Grænhöfðaeyjar',
	'UserCountry_country_cx' => 'Jólaey',
	'UserCountry_country_cy' => 'Kýpur',
	'UserCountry_country_cz' => 'Tékkland',
	'UserCountry_country_de' => 'Þýskaland',
	'UserCountry_country_dj' => 'Djíbútí',
	'UserCountry_country_dk' => 'Danmörk',
	'UserCountry_country_dm' => 'Dóminíka',
	'UserCountry_country_do' => 'Dóminíska lýðveldið',
	'UserCountry_country_dz' => 'Alsír',
	'UserCountry_country_ec' => 'Ekvador',
	'UserCountry_country_ee' => 'Eistland',
	'UserCountry_country_eg' => 'Egyptaland',
	'UserCountry_country_eh' => 'Vestur-Sahara',
	'UserCountry_country_er' => 'Erítrea',
	'UserCountry_country_es' => 'Spánn',
	'UserCountry_country_et' => 'Eþíópía',
	'UserCountry_country_eu' => 'Evrópusambandið',
	'UserCountry_country_fi' => 'Finnland',
	'UserCountry_country_fj' => 'Fídjieyjar',
	'UserCountry_country_fk' => 'Falklandseyjar',
	'UserCountry_country_fm' => 'Mikrónesía',
	'UserCountry_country_fo' => 'Færeyjar',
	'UserCountry_country_fr' => 'Frakkland',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Bretland',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgía',
	'UserCountry_country_gf' => 'Franska Gvæjana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Gana',
	'UserCountry_country_gi' => 'Gíbraltar',
	'UserCountry_country_gl' => 'Grænland',
	'UserCountry_country_gm' => 'Gambía',
	'UserCountry_country_gn' => 'Gínea',
	'UserCountry_country_gp' => 'Gvadelúpeyjar',
	'UserCountry_country_gq' => 'Miðbaugs-Gínea',
	'UserCountry_country_gr' => 'Grikkland',
	'UserCountry_country_gs' => 'Suður-Georgía og Suður-Sandvíkureyjar',
	'UserCountry_country_gt' => 'Gvatemala',
	'UserCountry_country_gu' => 'Gvam',
	'UserCountry_country_gw' => 'Gínea-Bissá',
	'UserCountry_country_gy' => 'Gvæjana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard og McDonalds-eyjar',
	'UserCountry_country_hn' => 'Hondúras',
	'UserCountry_country_hr' => 'Króatía',
	'UserCountry_country_ht' => 'Haítí',
	'UserCountry_country_hu' => 'Ungverjaland',
	'UserCountry_country_ic' => 'Kanaríeyjar',
	'UserCountry_country_id' => 'Indónesía',
	'UserCountry_country_ie' => 'Írland',
	'UserCountry_country_il' => 'Ísrael',
	'UserCountry_country_im' => 'Mön',
	'UserCountry_country_in' => 'Indland',
	'UserCountry_country_io' => 'Bresku Indlandshafseyjar',
	'UserCountry_country_iq' => 'Írak',
	'UserCountry_country_ir' => 'Íran',
	'UserCountry_country_is' => 'Ísland',
	'UserCountry_country_it' => 'Ítalía',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaíka',
	'UserCountry_country_jo' => 'Jórdanía',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenía',
	'UserCountry_country_kg' => 'Kirgisistan',
	'UserCountry_country_kh' => 'Kambódía',
	'UserCountry_country_ki' => 'Kíribatí',
	'UserCountry_country_km' => 'Kómoreyjar',
	'UserCountry_country_kn' => 'Sankti Kristófer og Nevis',
	'UserCountry_country_kp' => 'Norður-Kórea',
	'UserCountry_country_kr' => 'Suður-Kórea',
	'UserCountry_country_kw' => 'Kúveit',
	'UserCountry_country_ky' => 'Cayman-eyjar',
	'UserCountry_country_kz' => 'Kasakstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Líbanon',
	'UserCountry_country_lc' => 'Sankti Lúsía',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Srí Lanka',
	'UserCountry_country_lr' => 'Líbería',
	'UserCountry_country_ls' => 'Lesótó',
	'UserCountry_country_lt' => 'Litháen',
	'UserCountry_country_lu' => 'Lúxemborg',
	'UserCountry_country_lv' => 'Lettland',
	'UserCountry_country_ly' => 'Líbía',
	'UserCountry_country_ma' => 'Marokkó',
	'UserCountry_country_mc' => 'Mónakó',
	'UserCountry_country_md' => 'Moldóva',
	'UserCountry_country_me' => 'Svartfjallaland',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mh' => 'Marshall-eyjar',
	'UserCountry_country_mk' => 'Makedónía',
	'UserCountry_country_ml' => 'Malí',
	'UserCountry_country_mm' => 'Mjanmar',
	'UserCountry_country_mn' => 'Mongólía',
	'UserCountry_country_mo' => 'Makaó',
	'UserCountry_country_mp' => 'Norður-Maríanaeyjar',
	'UserCountry_country_mq' => 'Martiník',
	'UserCountry_country_mr' => 'Máritanía',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Máritíus',
	'UserCountry_country_mv' => 'Maldíveyjar',
	'UserCountry_country_mw' => 'Malaví',
	'UserCountry_country_mx' => 'Mexíkó',
	'UserCountry_country_my' => 'Malasía',
	'UserCountry_country_mz' => 'Mósambík',
	'UserCountry_country_na' => 'Namibía',
	'UserCountry_country_nc' => 'Nýja-Kaledónía',
	'UserCountry_country_ne' => 'Níger',
	'UserCountry_country_nf' => 'Norfolkeyja',
	'UserCountry_country_ng' => 'Nígería',
	'UserCountry_country_ni' => 'Níkaragva',
	'UserCountry_country_nl' => 'Holland',
	'UserCountry_country_no' => 'Noregur',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nárú',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Nýja-Sjáland',
	'UserCountry_country_om' => 'Óman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Perú',
	'UserCountry_country_pf' => 'Franska Pólýnesía',
	'UserCountry_country_pg' => 'Miðbaugs-Gínea',
	'UserCountry_country_ph' => 'Filippseyjar',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Pólland',
	'UserCountry_country_pm' => 'Sankti Pierre og Miquelon',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Púertó Ríkó',
	'UserCountry_country_ps' => 'Palestína',
	'UserCountry_country_pt' => 'Portúgal',
	'UserCountry_country_pw' => 'Palá',
	'UserCountry_country_py' => 'Paragvæ',
	'UserCountry_country_qa' => 'Katar',
	'UserCountry_country_re' => 'Réunion',
	'UserCountry_country_ro' => 'Rúmenía',
	'UserCountry_country_rs' => 'Serbía',
	'UserCountry_country_ru' => 'Rússland',
	'UserCountry_country_rw' => 'Rúanda',
	'UserCountry_country_sa' => 'Sádi-Arabía',
	'UserCountry_country_sb' => 'Salómonseyjar',
	'UserCountry_country_sc' => 'Seychelles-eyjar',
	'UserCountry_country_sd' => 'Súdan',
	'UserCountry_country_se' => 'Svíþjóð',
	'UserCountry_country_sf' => 'Finnland',
	'UserCountry_country_sg' => 'Singapúr',
	'UserCountry_country_sh' => 'Sankti Helena',
	'UserCountry_country_si' => 'Slóvenía',
	'UserCountry_country_sj' => 'Svalbarði og Jan Mayen',
	'UserCountry_country_sk' => 'Slóvakía',
	'UserCountry_country_sl' => 'Síerra Leóne',
	'UserCountry_country_sm' => 'San Marínó',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Sómalía',
	'UserCountry_country_sr' => 'Súrínam',
	'UserCountry_country_st' => 'Saó Tóme og Prinsípe',
	'UserCountry_country_su' => 'Sovétríkin',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Sýrland',
	'UserCountry_country_sz' => 'Svasíland',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks- og Caicos-eyjar',
	'UserCountry_country_td' => 'Tsjad',
	'UserCountry_country_tf' => 'Frönsku suðlægu landsvæðin',
	'UserCountry_country_tg' => 'Tógó',
	'UserCountry_country_th' => 'Taíland',
	'UserCountry_country_tj' => 'Tadsjikistan',
	'UserCountry_country_tk' => 'Tókelá',
	'UserCountry_country_tl' => 'Austur-Tímor',
	'UserCountry_country_tm' => 'Túrkmenistan',
	'UserCountry_country_tn' => 'Túnis',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Austur-Tímor',
	'UserCountry_country_tr' => 'Tyrkland',
	'UserCountry_country_tt' => 'Trínidad og Tóbagó',
	'UserCountry_country_tv' => 'Túvalú',
	'UserCountry_country_tw' => 'Taívan',
	'UserCountry_country_tz' => 'Tansanía',
	'UserCountry_country_ua' => 'Úkraína',
	'UserCountry_country_ug' => 'Úganda',
	'UserCountry_country_uk' => 'Bretland',
	'UserCountry_country_um' => 'Smáeyjar Bandaríkjanna',
	'UserCountry_country_us' => 'Bandaríkin',
	'UserCountry_country_uy' => 'Úrúgvæ',
	'UserCountry_country_uz' => 'Úsbekistan',
	'UserCountry_country_va' => 'Páfagarður (Vatíkanið)',
	'UserCountry_country_vc' => 'Sankti Vinsent og Grenadíneyjar',
	'UserCountry_country_ve' => 'Venesúela',
	'UserCountry_country_vg' => 'Jómfrúaeyjar (bresku)',
	'UserCountry_country_vi' => 'Jómfrúaeyjar',
	'UserCountry_country_vn' => 'Víetnam',
	'UserCountry_country_vu' => 'Vanúatú',
	'UserCountry_country_wf' => 'Wallis- og Fútúnaeyjar',
	'UserCountry_country_ws' => 'Bandaríska Samóa (Vestur-Samóa)',
	'UserCountry_country_ye' => 'Jemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Júgóslavía',
	'UserCountry_country_za' => 'Suður Afríka',
	'UserCountry_country_zm' => 'Sambía',
	'UserCountry_country_zr' => 'Zaíre',
	'UserCountry_country_zw' => 'Simbabve',
	'UserCountry_country_a1' => 'Nafnlaus milliþjónn',
	'UserCountry_country_a2' => 'Gerfihnattasamband',
	'UserCountry_country_ap' => 'Asía/Kyrrahafssvæði',
	'UserCountry_country_o1' => 'Annað land',
	'UserCountry_continent_eur' => 'Evrópa',
	'UserCountry_continent_afr' => 'Afríka',
	'UserCountry_continent_ant' => 'Suðurskautið',
	'UserCountry_continent_asi' => 'Asía',
	'UserCountry_continent_amn' => 'Norður Ameríka',
	'UserCountry_continent_amc' => 'Mið Ameríka',
	'UserCountry_continent_ams' => 'Suður Ameríka',
	'UserCountry_continent_oce' => 'Eyjaálfa',
	'UserSettings_PluginDescription' => 'Gefur skýrslu um ýmsar stillingar gesta:Vafra, Vafrafjölskyldu, Stýrikerfi, Íbætur, Skjáupplausn, altækar stillingar.',
	'UserSettings_VisitorSettings' => 'Stillingar gesta',
	'UserSettings_BrowserFamilies' => 'Vafrafjölskyldur',
	'UserSettings_Browsers' => 'Vafrar',
	'UserSettings_Plugins' => 'Íbætur',
	'UserSettings_Configurations' => 'Uppsetningar',
	'UserSettings_OperatingSystems' => 'Stýrikerfi',
	'UserSettings_Resolutions' => 'Skjáupplausnir',
	'UserSettings_WideScreen' => 'Breiðskjár',
	'UserSettings_ColumnBrowserFamily' => 'Vafrafjölskylda',
	'UserSettings_ColumnBrowser' => 'Vafri',
	'UserSettings_ColumnPlugin' => 'Íbót',
	'UserSettings_ColumnConfiguration' => 'Uppsetning',
	'UserSettings_ColumnOperatingSystem' => 'Stýrikerfi',
	'UserSettings_ColumnResolution' => 'Skjáupplausn',
	'UserSettings_ColumnTypeOfScreen' => 'Skjátegund',
	'UserSettings_WidgetResolutions' => 'Skjáupplausnir',
	'UserSettings_WidgetBrowsers' => 'Vafrar gesta',
	'UserSettings_WidgetPlugins' => 'Listi yfir íbætur',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => 'Ath: uppgötvun á íbótum virkar ekki með Internet Explorer. Þessi skýrsla er aðeins unnin út frá öðrum vöfrum en IE.',
	'UserSettings_WidgetWidescreen' => 'Normal/Breiðtjald',
	'UserSettings_WidgetBrowserFamilies' => 'Vafrar eftir fjölskyldu',
	'UserSettings_WidgetOperatingSystems' => 'Stýrikerfi',
	'UserSettings_WidgetGlobalVisitors' => 'Altæk gestastilling',
	'UserSettings_SubmenuSettings' => 'Stillingar',
	'UsersManager_UsersManagement' => 'Notendastjórnun',
	'UsersManager_Sites' => 'Vefir',
	'UsersManager_AllWebsites' => 'Allir vefir',
	'UsersManager_ApplyToAllWebsites' => 'Virkja fyrir alla vefi',
	'UsersManager_User' => 'Notandi',
	'UsersManager_PrivNone' => 'Engin aðgangur',
	'UsersManager_PrivView' => 'Sýn',
	'UsersManager_Password' => 'Lykilorð',
	'UsersManager_Email' => 'Netfang',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_ReportToLoadByDefault' => 'Skýrsla sem sjálfgefið er að sækja',
	'UsersManager_ForAnonymousUsersReportDateToLoadByDefault' => 'Sjálfgefið að sýna skýrslu fyrir notendur sem ekki eru auðkenndir',
	'UsersManager_ExcludeVisitsViaCookie' => 'Útiloka þínar heimsóknir með því að nota smáköku',
	'UsersManager_Edit' => 'Breyta',
	'UsersManager_AddUser' => 'Bæta nýjum notanda við',
	'UsersManager_MenuUsers' => 'Notendur',
	'UsersManager_MenuUserSettings' => 'Stillingar notenda',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => 'Vefsíðan sem óauðkenndir notendur fá',
	'UsersManager_ChangePassword' => 'Breyta lykilorði',
	'UsersManager_TheLoginScreen' => 'Skjár fyrir auðkenningu',
	'VisitFrequency_PluginDescription' => 'Skýrsla yfir ýmsa tölfræði um endurkomur versur nýja gesti.',
	'VisitFrequency_Evolution' => 'Þróun yfir tímabilið',
	'VisitFrequency_ColumnReturningVisits' => 'Endurkomur',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Aðgerðir við endurkomur',
	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => 'Meðalheimsóknatími fyrir endurkomur (í sekúndum)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Skopphraði fyrir endurkomur',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => 'Meðalfj. aðgerða fyrir endurkomur',
	'VisitFrequency_ReturnVisits' => '%s endurkomur',
	'VisitFrequency_ReturnActions' => '%s aðgerðir hjá endurkomum',
	'VisitFrequency_ReturnAvgActions' => '%s aðgerðir á hverja endurkomu',
	'VisitFrequency_ReturnAverageVisitDuration' => '%s meðalheimsóknartími fyrir endurkomur',
	'VisitFrequency_ReturnBounceRate' => '%s endurkomur hafa skoppað (yfirgefið vefinn eftir eina síðu)',
	'VisitFrequency_WidgetOverview' => 'Tíðniyfirlit',
	'VisitFrequency_WidgetGraphReturning' => 'Línurit yfir endurkomur',
	'VisitFrequency_SubmenuFrequency' => 'Tíðni',
	'VisitorInterest_PluginDescription' => 'Skýrslur um áhuga gestsins: fjöldi síðna sem eru skoðaðar, og tíma sem er eytt á vefnum.',
	'VisitorInterest_VisitsPerDuration' => 'Heimsóknir per lengd heimsóknar',
	'VisitorInterest_VisitsPerNbOfPages' => 'Heimsóknir per fjölda síðna',
	'VisitorInterest_ColumnVisitDuration' => 'Lengd heimsóknar',
	'VisitorInterest_ColumnPagesPerVisit' => 'Síður á hverja heimsókn',
	'VisitorInterest_WidgetLengths' => 'Lengd heimsókna',
	'VisitorInterest_WidgetPages' => 'Síður á hverja heimsókn',
	'VisitorInterest_Engagement' => 'Þáttaka',
	'VisitorInterest_PlusXMin' => '%s mín',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s mín',
	'VisitorInterest_OnePage' => '1 síða',
	'VisitorInterest_NPages' => '%s síður',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$ss',
	'VisitsSummary_PluginDescription' => 'Gefur skýrslu um almennar greiningartölur: heimsóknir, einstakir gestir, fjöldi aðgerða, skopptíðni, o.s.frv.',
	'VisitsSummary_VisitsSummary' => 'Samantekt heimsókna',
	'VisitsSummary_NbVisits' => '%s heimsóknir',
	'VisitsSummary_NbUniqueVisitors' => '%s einstakir gestir',
	'VisitsSummary_NbActionsDescription' => '%s aðgerðir (síðuflettingar, niðurhal og linkar frá vefnum)',
	'VisitsSummary_AverageVisitDuration' => '%s meðallengd heimsóknar',
	'VisitsSummary_MaxNbActions' => '%s hámark aðgerða í einni heimsókn',
	'VisitsSummary_NbActionsPerVisit' => '%s aðgerðir á heimsókn',
	'VisitsSummary_NbVisitsBounced' => '%s heimsóknir hafa skoppað (yfirgefið vefinn eftir eina síðu)',
	'VisitsSummary_GenerateTime' => '%s sekúndur að gera þessa síðu',
	'VisitsSummary_GenerateQueries' => '%s fyrirspurnir framkvæmdar',
	'VisitsSummary_WidgetLastVisits' => 'Línurit yfir síðustu heimsóknir',
	'VisitsSummary_WidgetVisits' => 'Heimsóknayfirlit',
	'VisitsSummary_WidgetLastVisitors' => 'Línurit yfir síðustu einstaka gesti',
	'VisitsSummary_WidgetOverviewGraph' => 'Yfirlit með línuriti',
	'VisitsSummary_SubmenuOverview' => 'Yfirlit',
	'VisitTime_PluginDescription' => 'Sýnir Staðartíma og tímabelti þjónsins. Þetta getur verið nytsamt til að láta vita um viðhald vefsins.',
	'VisitTime_LocalTime' => 'Heimsóknir miðað við staðartíma',
	'VisitTime_ServerTime' => 'Heimsóknir miðað við tíma vefþjóns',
	'VisitTime_ColumnServerTime' => 'Tímabelti þjóns',
	'VisitTime_ColumnLocalTime' => 'Staðartími',
	'VisitTime_WidgetLocalTime' => 'Heimsóknir skv. staðartíma',
	'VisitTime_WidgetServerTime' => 'Heimsóknir skv. tímabelti þjóns',
	'VisitTime_SubmenuTimes' => 'Tímar',
	'VisitTime_NHour' => '%st',
	'PDFReports_EmailReports' => 'Senda skýrslur með tölvupósti',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_SendReportNow' => 'Senda skýrslu strax',
	'PDFReports_EmailSchedule' => 'Tímaáætlun fyrir tölvupóst',
	'PDFReports_SendReportTo' => 'Senda skýrslu til',
	'PDFReports_SentToMe' => 'Senda mér',
	'PDFReports_WeeklyScheduleHelp' => 'Vikuleg tímaáætlun: skýrsla er send hvern mánudag.',
	'PDFReports_MonthlyScheduleHelp' => 'Mánaðarleg tímaáætlun: skýrsla er send fyrsta dag hvers mánaðar.',
	'PDFReports_AlsoSendReportToTheseEmails' => 'Senda skýrsluna einnig á þessi netföng (eitt í hverja línu):',
	'PDFReports_PiwikReports' => 'Piwik skýrslur',
	'PDFReports_EmailHello' => 'Halló,',
	'PDFReports_PleaseFindAttachedFile' => 'Gjörðu svo vel að skoða skýrslu um %2$s í skránni %1$s sem er hjálögð.',
	'UserLanguage_Language_aa' => 'afár',
	'UserLanguage_Language_ab' => 'abkasíska',
	'UserLanguage_Language_ae' => 'avestíska',
	'UserLanguage_Language_af' => 'afríkanska',
	'UserLanguage_Language_ak' => 'akan',
	'UserLanguage_Language_am' => 'amharíska',
	'UserLanguage_Language_an' => 'aragonska',
	'UserLanguage_Language_ar' => 'arabíska',
	'UserLanguage_Language_as' => 'assamska',
	'UserLanguage_Language_av' => 'avaríska',
	'UserLanguage_Language_ay' => 'aímara',
	'UserLanguage_Language_az' => 'aserska',
	'UserLanguage_Language_ba' => 'baskír',
	'UserLanguage_Language_be' => 'hvítrússneska',
	'UserLanguage_Language_bg' => 'búlgarska',
	'UserLanguage_Language_bh' => 'bíharí',
	'UserLanguage_Language_bi' => 'bíslama',
	'UserLanguage_Language_bm' => 'bambara',
	'UserLanguage_Language_bn' => 'bengalska',
	'UserLanguage_Language_bo' => 'tíbeska',
	'UserLanguage_Language_br' => 'bretónska',
	'UserLanguage_Language_bs' => 'bosníska',
	'UserLanguage_Language_ca' => 'katalónska',
	'UserLanguage_Language_ce' => 'tsjetsjenska',
	'UserLanguage_Language_ch' => 'kamorró',
	'UserLanguage_Language_co' => 'korsíska',
	'UserLanguage_Language_cr' => 'krí',
	'UserLanguage_Language_cs' => 'tékkneska',
	'UserLanguage_Language_cu' => 'kirkjuslavneska',
	'UserLanguage_Language_cv' => 'sjúvas',
	'UserLanguage_Language_cy' => 'velska',
	'UserLanguage_Language_da' => 'danska',
	'UserLanguage_Language_de' => 'þýska',
	'UserLanguage_Language_dv' => 'dívehí',
	'UserLanguage_Language_dz' => 'dsongka',
	'UserLanguage_Language_ee' => 'eve',
	'UserLanguage_Language_el' => 'nýgríska (1453-)',
	'UserLanguage_Language_en' => 'enska',
	'UserLanguage_Language_eo' => 'esperantó',
	'UserLanguage_Language_es' => 'spænska',
	'UserLanguage_Language_et' => 'eistneska',
	'UserLanguage_Language_eu' => 'baskneska',
	'UserLanguage_Language_fa' => 'persneska',
	'UserLanguage_Language_ff' => 'fúla',
	'UserLanguage_Language_fi' => 'finnska',
	'UserLanguage_Language_fj' => 'fídjeyska',
	'UserLanguage_Language_fo' => 'færeyska',
	'UserLanguage_Language_fr' => 'franska',
	'UserLanguage_Language_fy' => 'frísneska',
	'UserLanguage_Language_ga' => 'írska',
	'UserLanguage_Language_gd' => 'skosk gelíska',
	'UserLanguage_Language_gl' => 'gallegska',
	'UserLanguage_Language_gn' => 'gvaraní',
	'UserLanguage_Language_gu' => 'gújaratí',
	'UserLanguage_Language_gv' => 'manx',
	'UserLanguage_Language_ha' => 'hása',
	'UserLanguage_Language_he' => 'hebreska',
	'UserLanguage_Language_hi' => 'hindí',
	'UserLanguage_Language_ho' => 'hírímótú',
	'UserLanguage_Language_hr' => 'króatíska',
	'UserLanguage_Language_ht' => 'haítíska',
	'UserLanguage_Language_hu' => 'ungverska',
	'UserLanguage_Language_hy' => 'armenska',
	'UserLanguage_Language_hz' => 'hereró',
	'UserLanguage_Language_ia' => 'interlingva',
	'UserLanguage_Language_id' => 'indónesíska',
	'UserLanguage_Language_ie' => 'interlingve',
	'UserLanguage_Language_ig' => 'ígbó',
	'UserLanguage_Language_ii' => 'sísúanjí',
	'UserLanguage_Language_ik' => 'ínúpíak',
	'UserLanguage_Language_io' => 'ídó',
	'UserLanguage_Language_is' => 'íslenska',
	'UserLanguage_Language_it' => 'ítalska',
	'UserLanguage_Language_iu' => 'inúktitút',
	'UserLanguage_Language_ja' => 'japanska',
	'UserLanguage_Language_jv' => 'javanska',
	'UserLanguage_Language_ka' => 'georgíska',
	'UserLanguage_Language_kg' => 'kongó',
	'UserLanguage_Language_ki' => 'kíkújú',
	'UserLanguage_Language_kj' => 'kúanjama',
	'UserLanguage_Language_kk' => 'kasakska',
	'UserLanguage_Language_kl' => 'grænlenska',
	'UserLanguage_Language_km' => 'kmer',
	'UserLanguage_Language_kn' => 'kannada',
	'UserLanguage_Language_ko' => 'kóreska',
	'UserLanguage_Language_kr' => 'kanúrí',
	'UserLanguage_Language_ks' => 'kasmírska',
	'UserLanguage_Language_ku' => 'kúrdneska',
	'UserLanguage_Language_kv' => 'komíska',
	'UserLanguage_Language_kw' => 'korníska',
	'UserLanguage_Language_ky' => 'kirgiska',
	'UserLanguage_Language_la' => 'latína',
	'UserLanguage_Language_lb' => 'lúxemborgíska',
	'UserLanguage_Language_lg' => 'ganda',
	'UserLanguage_Language_li' => 'limbúrgíska',
	'UserLanguage_Language_ln' => 'lingala',
	'UserLanguage_Language_lo' => 'laó',
	'UserLanguage_Language_lt' => 'litháíska',
	'UserLanguage_Language_lu' => 'lúbakatanga',
	'UserLanguage_Language_lv' => 'lettneska',
	'UserLanguage_Language_mg' => 'malagasíska',
	'UserLanguage_Language_mh' => 'marshallska',
	'UserLanguage_Language_mi' => 'maórí',
	'UserLanguage_Language_mk' => 'makedónska',
	'UserLanguage_Language_ml' => 'malajalam',
	'UserLanguage_Language_mn' => 'mongólska',
	'UserLanguage_Language_mr' => 'maratí',
	'UserLanguage_Language_ms' => 'malaíska',
	'UserLanguage_Language_mt' => 'maltneska',
	'UserLanguage_Language_my' => 'burmneska',
	'UserLanguage_Language_na' => 'nárúska',
	'UserLanguage_Language_nb' => 'norskt bókmál',
	'UserLanguage_Language_nd' => 'norðurndebele',
	'UserLanguage_Language_ne' => 'nepalska',
	'UserLanguage_Language_ng' => 'ndonga',
	'UserLanguage_Language_nl' => 'hollenska',
	'UserLanguage_Language_nn' => 'nýnorska',
	'UserLanguage_Language_no' => 'norska',
	'UserLanguage_Language_nr' => 'suðurndebele',
	'UserLanguage_Language_nv' => 'navahó',
	'UserLanguage_Language_ny' => 'Njanja; Sísjeva; Sjeva',
	'UserLanguage_Language_oc' => 'Okkitíska (eftir 1500); Próvensalska',
	'UserLanguage_Language_oj' => 'ojibva',
	'UserLanguage_Language_om' => 'órómó',
	'UserLanguage_Language_or' => 'óría',
	'UserLanguage_Language_os' => 'ossetíska',
	'UserLanguage_Language_pa' => 'púnjabí',
	'UserLanguage_Language_pi' => 'palí',
	'UserLanguage_Language_pl' => 'pólska',
	'UserLanguage_Language_ps' => 'pastú',
	'UserLanguage_Language_pt' => 'portúgalska',
	'UserLanguage_Language_qu' => 'kvesjúa',
	'UserLanguage_Language_rm' => 'retórómanska',
	'UserLanguage_Language_rn' => 'rúndí',
	'UserLanguage_Language_ro' => 'rúmenska',
	'UserLanguage_Language_ru' => 'rússneska',
	'UserLanguage_Language_rw' => 'kínjarvanda',
	'UserLanguage_Language_sa' => 'sanskrít',
	'UserLanguage_Language_sc' => 'sardínska',
	'UserLanguage_Language_sd' => 'sindí',
	'UserLanguage_Language_se' => 'norðursamíska',
	'UserLanguage_Language_sg' => 'sangó',
	'UserLanguage_Language_si' => 'singalesíska',
	'UserLanguage_Language_sk' => 'slóvakíska',
	'UserLanguage_Language_sl' => 'slóvenska',
	'UserLanguage_Language_sm' => 'samóska',
	'UserLanguage_Language_sn' => 'shóna',
	'UserLanguage_Language_so' => 'sómalska',
	'UserLanguage_Language_sq' => 'albanska',
	'UserLanguage_Language_sr' => 'serbneska',
	'UserLanguage_Language_ss' => 'svatí',
	'UserLanguage_Language_st' => 'suðursótó',
	'UserLanguage_Language_su' => 'súndanska',
	'UserLanguage_Language_sv' => 'sænska',
	'UserLanguage_Language_sw' => 'svahílí',
	'UserLanguage_Language_ta' => 'tamílska',
	'UserLanguage_Language_te' => 'telúgú',
	'UserLanguage_Language_tg' => 'tadsjikska',
	'UserLanguage_Language_th' => 'taílenska',
	'UserLanguage_Language_ti' => 'tígrinja',
	'UserLanguage_Language_tk' => 'túrkmenska',
	'UserLanguage_Language_tl' => 'tagalog',
	'UserLanguage_Language_tn' => 'tsúana',
	'UserLanguage_Language_to' => 'Tongverska (Tongaeyjar)',
	'UserLanguage_Language_tr' => 'tyrkneska',
	'UserLanguage_Language_ts' => 'tsonga',
	'UserLanguage_Language_tt' => 'tatarska',
	'UserLanguage_Language_tw' => 'tví',
	'UserLanguage_Language_ty' => 'tahítíska',
	'UserLanguage_Language_ug' => 'úígúr',
	'UserLanguage_Language_uk' => 'úkraínska',
	'UserLanguage_Language_ur' => 'úrdú',
	'UserLanguage_Language_uz' => 'úsbekska',
	'UserLanguage_Language_ve' => 'venda',
	'UserLanguage_Language_vi' => 'víetnamska',
	'UserLanguage_Language_vo' => 'volapyk',
	'UserLanguage_Language_wa' => 'vallónska',
	'UserLanguage_Language_wo' => 'volof',
	'UserLanguage_Language_xh' => 'sósa',
	'UserLanguage_Language_yi' => 'jiddíska',
	'UserLanguage_Language_yo' => 'jórúba',
	'UserLanguage_Language_za' => 'súang',
	'UserLanguage_Language_zh' => 'kínverska',
	'UserLanguage_Language_zu' => 'súlú',
);
